import { IRole, PolicyStatement } from 'aws-cdk-lib/aws-iam';
import { SingletonFunction } from 'aws-cdk-lib/aws-lambda';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { DefinitionBody, IChainable, StateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { StateMachineProps } from 'aws-cdk-lib/aws-stepfunctions/lib/state-machine';
import { ApplicationConfiguration } from 'aws-cdk-lib/aws-stepfunctions-tasks';
import { Construct } from 'constructs';
import { EzConstruct } from '../ez-construct';
export declare class SimpleStepFunction extends EzConstruct {
    /** @internal */ _account: string;
    /** @internal */ _region: string;
    /** @internal */ _name: string;
    /** @internal */ _policies: PolicyStatement[];
    /** @internal */ _stateMachine?: StateMachine;
    /** @internal */ _stateMachineRole?: IRole;
    /** @internal */ _stateDefinition?: IChainable | string;
    /** @internal */ _stateDefinitionBody?: DefinitionBody;
    /** @internal */ _defaultInputs: any;
    /** @internal */ _grantee?: IRole;
    private readonly _scope;
    private readonly _id;
    constructor(scope: Construct, id: string, stepFunctionName: string);
    get account(): string;
    get region(): string;
    get scope(): Construct;
    get id(): string;
    get defaultInputs(): any;
    /**
     * The state machine instance created by this construct.
     * @returns {StateMachine}
     */
    get stateMachine(): StateMachine;
    get policies(): PolicyStatement[];
    get stateMachineRole(): IRole;
    /**
     * Returns the state definition as a string if the original state definition used was string.
     * Otherwise returns empty string.
     */
    get stateDefinitionAsString(): string;
    /**
     * Sets the state definition, and if type of the value passed is a string,
     * will also set the stateDefinition when it is a string.
     * @param value
     */
    set stateDefinition(value: IChainable | string);
    /**
     * Returns the state definition body object
     */
    get stateDefinitionBody(): DefinitionBody;
    /**
     * Creates state machine from the given props
     * @param stateMachineProps
     */
    createStateMachine(stateMachineProps: StateMachineProps): StateMachine;
    /**
     * Will add default permisisons to the step function role
     */
    generateDefaultStateMachinePermissions(): void;
    addPolicy(policy: PolicyStatement): SimpleStepFunction;
    usingStringDefinition(stateDefinition: string): SimpleStepFunction;
    usingChainableDefinition(stateDefinition: IChainable): SimpleStepFunction;
    /**
     * Modifies the supplied state definition string version of workflow defintion to include logging and tracing.
     * @param stateDef - the state definition string
     * @private
     */
    modifyStateDefinition(stateDef: string): string;
    /**
     * Default inputs of the spark jobs. Example:-
     *  ```
     *  .withDefaultInputs({
     *      "SparkSubmitParameters": {
     *        "--conf spark.executor.memory=2g",
     *        "--conf spark.executor.cores=2"
     *      },
     *      "greetings": "Good morning",
     *      "personal": {
     *        "name": "John Doe",
     *        "age": 30
     *      }
     *   })
     *  ```
     * @param params
     */
    withDefaultInputs(params: any): SimpleStepFunction;
    /**
     * Grants pass role permissions to the state machine role
     */
    grantPassRole(role: IRole): SimpleStepFunction;
    /**
     * Assembles the state machine.
     * @param stateMachineProps
     */
    assemble(stateMachineProps?: StateMachineProps): SimpleStepFunction;
    /**
     * creates state machine role
     */
    createStateMachineRole(stateMachineName: string): IRole;
    /**
     * creates bucket to store state machine logs
     */
    createStateMachineCloudWatchLogGroup(): ILogGroup;
    createDefaultStateMachineProps(stateMachineName: string, stateMachineRole: IRole, definitionBody: DefinitionBody, logGroup: ILogGroup): StateMachineProps;
}
/**
 * A standard spark submit job template.
 */
export interface StandardSparkSubmitJobTemplate {
    /**
     * The name of the job.*required*
     */
    readonly jobName: string;
    /**
     * The S3 URL of the spark application's main file in Amazon S3.
     * A jar file for Scala and Java Spark applications and a Python file for pySpark applications.
     */
    readonly entryPoint: string;
    /**
     * The names of the arguments to pass to the application.
     * The actual argument value should be specified during step funciton execution time.
     */
    readonly entryPointArgumentNames?: string[];
    /**
     * The name of the application's main class,only applicable for Java/Scala Spark applications.
     */
    readonly mainClass?: string;
    /**
     * The arguments to pass to the application.
     */
    readonly sparkSubmitParameters?: string;
    /**
     * Any version of overrides to use while provisioning EMR job.
     */
    readonly applicationConfiguration?: ApplicationConfiguration[];
    /**
     * True if monitoring must be enabled. Defaults to true.
     */
    readonly enableMonitoring?: boolean;
}
/**
 * This construct will create a Step function workflow that can submit spark job.
 * If you utilize the @see SandardSparkSubmitJobTemplate, the workflow generated will consist of a single spark job.
 * If you need a much elaborate workflow, you can provide a string version of the state definition, while initializing the construct.
 *
 * @example
 *  There are many instances where an ETL job may only have a single spark job. In such cases, you can use the @see StandardSparkSubmitJobTemplate.
 *  The `usingDefinition` method will take care of capturing variables, like `entryPoint`, `mainClass` etc .
 *  By default the step function during execution utilize those variable values as default.
 *  It is quite common that the JAR files used for the spark job may be different. To address that, 'EntryPoint` and `SparkSubmitParameters` variables are externalized and can be overriden during execution.
 * ```typescript
 * new SimpleServerlessSparkJob(mystack, 'SingleFly', 'MyTestETL)
 *  .jobRole('delegatedadmin/developer/blames-emr-serverless-job-role')
 *  .applicationId('12345676')
 *  .logBucket('mylogbucket-name')
 *  .usingDefinition({
 *         jobName: 'mytestjob',
 *         entryPoint: 's3://aws-cms-amg-qpp-costscoring-artifact-dev-222224444433-us-east-1/biju_test_files/myspark-assembly.jar',
 *         mainClass: 'serverless.SimpleSparkApp',
 *         enableMonitoring: true,
 *    })
 *  .assemble();
 *  ```
 * Having seen the above simple example, let us look at a more elaborate example, where the step function workflow is complex.
 * It is possible to author the step function workflow JSON file and provide it as a string to the `usingDefinition` method.
 * ```typescript
 *  new SimpleServerlessSparkJob(mystackObj, 'MultiFly', 'MyAwesomeETL)
 *  .jobRole('delegatedadmin/developer/blames-emr-serverless-job-role')
 *  .applicationId('12345676')
 *  .logBucket('mylogbucket-name')
 *  .usingDefinition("{...json step function string.... }")
 *  .assemble();
 * ```
 * If we have to read differnent input parameters for the spark job, we can have variables that extract values from the context.
 * ```typescript
 * new SimpleServerlessSparkJob(mystackObj, 'MultiFly')
 *  .name('MyAwesomeETL')
 *  .jobRole('delegatedadmin/developer/blames-emr-serverless-job-role')
 *  .applicationId('12345676')
 *  .logBucket('mylogbucket-name')
 *  .usingDefinition("{...json step function string.... }")
 *  .withDefaultInputs({"some":"thing", "other": "thing"})
 *  .assemble();
 *  ```
 *
 */
export declare class SimpleServerlessSparkJob extends SimpleStepFunction {
    private _validatorLambdaFn?;
    private _replacerLambdaFn?;
    private _logBucket?;
    private _jobRole?;
    private _jobRoleArn?;
    private _singleSparkJobTemplate?;
    private _applicationId?;
    private _applicationArn?;
    constructor(scope: Construct, id: string, stepFunctionName: string);
    get validatorLambdaFn(): SingletonFunction;
    get replacerLambdaFn(): SingletonFunction;
    /**
     * The role the spark job will assume while executing jobs in EMR.
     * @param name - a qualified name including the path. e.g. `path/to/roleName`
     */
    jobRole(name: string): SimpleServerlessSparkJob;
    /**
     * The serverless application ID, and to that application the jobs will be submitted.
     * @param applicaitonId
     */
    applicationId(applicaitonId: string): SimpleServerlessSparkJob;
    /**
     * A bucket to store the logs producee by the Spark jobs.
     * @param bucket
     */
    logBucket(bucket: string | IBucket): SimpleServerlessSparkJob;
    private regeneateJobRoleArn;
    private regenerateApplicationArn;
    private mergeConfigOverrides;
    /**
     * Modifies the supplied state definition string version of workflow defintion to include logging and tracing.
     * @param aDef - the state definition string
     * @private
     */
    modifyStateDefinition(aDef: string): string;
    /**
     * Will create a state definition object based on the supplied StandardSparkSubmitJobTemplate object.
     * @private
     */
    private createStateDefinition;
    /**
     * Will create a state definition object based on the supplied StandardSparkSubmitJobTemplate object.
     * @param sparkJobTemplate
     */
    usingSparkJobTemplate(sparkJobTemplate: StandardSparkSubmitJobTemplate): SimpleServerlessSparkJob;
    /**
     * Will add default permisisons to the step function role
     */
    generateDefaultStateMachinePermissions(): void;
    /**
     * Will create replacements of text in %KEY%, with actual value of the KEY
     * @private
     */
    private createReplacementFn;
    /**
     * Will create the validator lambda function that can validate entrypoint args
     * @private
     */
    private createValidatorFn;
    assemble(stateMachineProps?: StateMachineProps): SimpleStepFunction;
}
